window.Gleam.initSearch([{"doc":"glerd_valid","title":"glerd_valid","content":"# glerd_valid\n\n[![Package Version](https://img.shields.io/hexpm/v/glerd_valid)](https://hex.pm/packages/glerd_valid)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/glerd_valid/)\n![Erlang-compatible](https://img.shields.io/badge/target-erlang-a2003e)\n![JavaScript-compatible](https://img.shields.io/badge/target-javascript-f1e05a)\n\nGleam Record validators using Glerd metadata\n\n```sh\ngleam add --dev glerd glerd_valid\n```\n\n#### 1. Describe your records with validation metadata\n\nExample:\n\n```gleam\npub type Cat {\n  /// valid:name:length:&#39;gte=3, lt=50&#39;\n  /// valid:lives_count:self:&#39;min=1, max=9&#39;\n  Cat(name: String, lives_count: Int)\n}\n```\n\n#### 2. Generate Records info\n\nUse [Glerd](https://github.com/darky/glerd)\n\n#### 3. Make module for validators generation\n\n###### my_module.gleam\n\n```gleam\nimport glerd_valid\nimport glerd_gen\n\npub fn main() {\n  glerd_gen.record_info\n  |&gt; glerd_valid.generate(&quot;src&quot;, _)\n}\n```\n\n#### 4. Gen validators\n\n```sh\ngleam run -m my_module\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/glerd_valid&gt;.\n\n## Supported metadata\n\n#### Operators\n\n| operator | description                        |\n|----------|------------------------------------|\n| gte, min | should be greater than or equal to |\n| gt       |  should be greater than            |\n| lte, max |  should be less than or equal to   |\n| lt       |  should be less than               |\n| eq       |  should be equal to                |\n| ne       |  should not be equal to            |\n\n#### Levels\n\n| level  | description                  |\n|--------|------------------------------|\n| self   | check on Record field itself |\n| length | check on Record field length |\n\n#### Compatibility\n\n| operator | level  | type   |\n|----------|--------|--------|\n| gte, min | self   | Int    |\n| gte, min | self   | Float  |\n| gte, min | length | String |\n| gte, min | length | List   |\n|                            |\n| gt       | self   | Int    |\n| gt       | self   | Float  |\n| gt       | length | String |\n| gt       | length | List   |\n|                            |\n| lte, max | self   | Int    |\n| lte, max | self   | Float  |\n| lte, max | length | String |\n| lte, max | length | List   |\n|                            |\n| lt       | self   | Int    |\n| lt       | self   | Float  |\n| lt       | length | String |\n| lt       | length | List   |\n|                            |\n| eq       | self   | Int    |\n| eq       | self   | Float  |\n| eq       | self   | String |\n| eq       | self   | List   |\n| eq       | self   | Bool   |\n| eq       | length | String |\n| eq       | length | List   |\n|                            |\n| ne       | self   | Int    |\n| ne       | self   | Float  |\n| ne       | self   | String |\n| ne       | self   | List   |\n| ne       | self   | Bool   |\n| ne       | length | String |\n| ne       | length | List   |\n\n## Development\n\n```sh\ngleam test # and then commit generated file\n```\n","url":"index.html"},{"doc":"glerd_valid","title":"generate","content":"pub fn generate(\n  root: String,\n  record_info: List(\n    #(String, String, List(#(String, FieldType)), String),\n  ),\n) -&gt; Nil\n\nSynonyms:\nglerd_valid.generate\nglerd_valid generate","url":"glerd_valid.html#generate"},{"doc":"glerd_valid","title":"glerd_valid","content":"","url":"glerd_valid.html"}]);